==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/skoleni/prihlaseninaplanovaneskolenicontroller.php <==
<?php
/**
 * stanislav.elbl, 01.08.2021 10:51
 */

namespace RonPortal\Skoleni;

use Exception;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\Http\HtmlHeaders;
use Ron\MessageManager;
use Ron\MVC\InternalRedirect;
use Ron\MVC\JsonOutputObject;
use Ron\MVC\OutputObject;
use Ron\MVC\Redirect;
use Ron\MVC\ViewObject;
use Ron\StringUtils;
use Ron\TextManager;
use Ron\MVC\HttpController;
use RonPortal\NeniPravoException;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;
use RonPortal\RonPortalDBRecord;
use RonPortal\RonPortalUtils;
use RonPortal\User;


/**
 * Class PrihlaseniNaPlanovaneSkoleniController
 * @package Ron\RonPortal
 */
class PrihlaseniNaPlanovaneSkoleniController extends HttpController
{
    /** @var  PravaNaOsoby $pravoPrihlasit */
    public $pravoPrihlasit;

    /** @var  Database */
    private $database;

    /** @var PravaNaOsoby $pravoSchvalit */
    public $pravoSchvalit;

    /**
     * PrihlaseniNaPlanovaneSkoleniController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
        $this->pravoPrihlasit = Prava::vratPrava('skoleni_prihlasit');
        $this->pravoSchvalit = Prava::vratPrava('skoleni_schvaleni_planu');
        Prava::nastavObdobiProPrava(time(), time());

        TextManager::getInstance()->loadStrings('prihlaseninaplanovanaskoleni.ini');

        HtmlHeaders::getInstance()->addCss("css/skoleni.css");
        HtmlHeaders::getInstance()->addCss("css/s_ron.css");
        HtmlHeaders::getInstance()->addScript('script/skolenihodnoceni.js'); // TODO: predelat, presunout a odstranit
        HtmlHeaders::getInstance()->addScript('script/skoleni.js');

        $this ->addTranslationsScript('skoleni');
    }


    /**
     * @param $cisloSkoleni
     * @return Redirect
     * @throws Exception
     */
    public function prihlaseniNaPlanovaneSkoleni($cisloSkoleni)
    {
        if (!$this->pravoPrihlasit->lzeZobrazitRC(User::getRC()) && !$this->pravoSchvalit->lzeZobrazitRC(User::getRC())) {
            throw new NeniPravoException();
        }

        try {
            //Dotaz na volne misto
            $volnaMista = SkoleniUtils::volnaKapacitaSkoleni($this ->database, $cisloSkoleni);

            if ($volnaMista <= 0) {
                throw new Exception(TextManager::_('chyba_kapacita_kurzu_naplnena'));
            }

            $recZapis = new RonPortalDBRecord($this->database, 'PlanovaneSkoleniOsob', $this);

            $recZapis->addField('CisloSkoleni', '', false, 10, $cisloSkoleni);
            $recZapis->addField('RC', '', false, 15, User::getRC());
            //Pokud ma pravo schvalit sebe
            $muzeSchvalit = $this->pravoSchvalit->lzeZobrazitRC(User::getRC());
            $recZapis->addField('Potvrzeni', 'int', false, 0, ($muzeSchvalit) ? 1 : 0);
            $recZapis->addField('DatumVlozeni', 'timestamp', false, 0, time());
            $recZapis->addField('Vlozil', '', false, 25, User::getRC());
            $recZapis->addField('Vyhodnotil', '', false, 25, '');
            $recZapis->addField('PrihlasenoZAplikace', 'int', false, 0, 1);
            $recZapis->addField('DatumVyhodnoceni', 'timestamp', false, 0, '');

            $params = $this->database->createParameters();
            $recZapis->setWhere(
                'RC  = ' . $params->addParameter(User::getRC()) .
                ' AND CisloSkoleni = ' . $params->addParameter($cisloSkoleni),
                $params);

            if ($recZapis->loadRecord()) {
                throw new Exception(TextManager::_('chyba_osoba_na_skoleni_uz_prihlasena'));
            }

            $recZapis->insertRecord();
        } catch (Exception $e) {
            MessageManager::addErrorMessage($e);
        }

        return new Redirect(null,
            '?menuid=skoleni&action=prihlaseninaplanovaneskoleni');
    }


    /**
     * @param $cisloSkoleni
     * @return Redirect
     * @throws Exception
     */
    public function odhlaseniZPlanovanehoSkoleni($cisloSkoleni)
    {
        if (!$this->pravoPrihlasit->lzeZobrazitRC(User::getRC()) && !$this->pravoSchvalit->lzeZobrazitRC(User::getRC())){
            RonPortalUtils::neniPravoException();
        }

        $recZapis = new RonPortalDBRecord($this->database, 'PlanovaneSkoleniOsob');

        $params = $this->database->createParameters();
        $recZapis->logDescription = StringUtils::fromUTF8('Plánované školení - odhlašování z plánovaného školení');
        $recZapis->addField('CisloSkoleni', '', false);
        $recZapis->addField('RC', '', false);
        $recZapis->addField('Potvrzeni', '', false);
        $recZapis->addField('Vlozil', '', false);
        $recZapis->addField('DatumVlozeni', 'timestamp', false);
        $recZapis->addField('Vyhodnotil', '', false);
        $recZapis->addField('DatumVyhodnoceni', 'timestamp', false);
        $recZapis->addField('PrihlasenoZAplikace', '', false);

        $recZapis->setWhere( 'RC  = ' . $params->addParameter(User::getRC()) .
            ' AND CisloSkoleni = ' . $params->addParameter($cisloSkoleni), $params);

        if (!$recZapis->deleteRecord()) {
            throw new Exception(StringUtils::fromUTF8('Chyba při odhlašování z plánovaného školení.'));
        }

        $filtrprihlaseninaplanovaneskoleni = $_SESSION['filtrprihlaseninaplanovaneskoleni'];
        return new Redirect(null, "?menuid=skoleni&action=prihlaseninaplanovaneskoleni&filtrprihlaseninaplanovaneskoleni=$filtrprihlaseninaplanovaneskoleni");
    }



    /**
     * @param string $cisloSkoleni
     * @param int    $osoba
     * @param int    $potvrzeni     0=bez rozhodnuti, 1=schvaleno, 2=zamitnuto
     * @param string $poznamkaSchvalovani
     * @param int    $hromadne      Urcuje, jestli se ma presmerovat na hromadne prihlasovani, nebo na prihlasovani osoby
     * @return Redirect
     * @throws Exception
     * @throws NeniPravoException
     */
    public function schvalitPlanKurzuZamestnance($cisloSkoleni, $osoba, $potvrzeni, $poznamkaSchvalovani=null, $hromadne = 0)
    {
        if (!$cisloSkoleni || !$osoba){
            throw new Exception(\Ron\ronText('chyba_nezadano_cislo_skoleni_nebo_osoba'));
        }

        $pp = PracovniPomer::nactiPP($this->database, $osoba);

        if (!$this->pravoPrihlasit->lzeZobrazitPP($pp->idPP) && !$this->pravoSchvalit->lzeZobrazitPP($pp->idPP)){
            throw new NeniPravoException();
        }

        try {
            //Dotaz na volne misto
            $volnaMista = SkoleniUtils::volnaKapacitaSkoleni($this ->database, $cisloSkoleni);

            if ($volnaMista <= 0) {
                MessageManager::addErrorMessage(\Ron\ronText('kapacita_kurzu_naplnena'));
            }

            $muzeSchvalit = $this->pravoSchvalit->lzeZobrazitRC($pp->rc);

            $recZapis = new RonPortalDBRecord($this->database, 'PlanovaneSkoleniOsob', $this);

            $recZapis->addField('CisloSkoleni', '', false, 10, $cisloSkoleni);
            $recZapis->addField('RC', '', false, 15, $pp->rc);

            // Pokud ma pravo schvalit danou osobu tak primo schvalit
            $recZapis->addField('Potvrzeni', 'int', !$muzeSchvalit, 0, ($muzeSchvalit) ? $potvrzeni : 0);
            $recZapis->addField('Vlozil', '', true, 25, RonPortalUtils::getLogUserName());
            $recZapis->addField('DatumVlozeni', 'timestamp', true, 0, time());
            $recZapis->addField('Vyhodnotil', '', true, 25, '');
            $recZapis->addField('DatumVyhodnoceni', 'timestamp', true, 0, '');
            $recZapis->addField('PrihlasenoZAplikace', 'int', true, 0, 1);

            //pri odhlaseni zustane poznamka zachovana
            $recZapis->addMemoField('PoznamkaSchvalovani', !isset($poznamkaSchvalovani), $poznamkaSchvalovani);

            $params = $this->database->createParameters();
            $recZapis->setWhere(
                'RC  = ' . $params->addParameter($pp->rc) .
                ' AND CisloSkoleni = ' . $params->addParameter($cisloSkoleni),
                $params);


            $recZapis->updateOrInsert();
        } catch (Exception $e) {
            MessageManager::addErrorMessage($e);
        }

//        if ($ajax){
//            //Pokud je prihlaseni/schvaleni pomoci dialogu via ajax
//            $json = new JsonOutputObject();
//            $json->setResult('OK');
//            return $json;
//        }

        $redirectFiltr = $hromadne ? 'planypodlekurzu' : 'planypodleosoby';
        return new Redirect(null, "?menuid=skoleni&action=prihlaseninaplanovaneskoleni&filtrprihlaseninaplanovaneskoleni=$redirectFiltr");
    }


    /**
     * @param string $cisloSkoleni
     * @param int $osoba
     * @return bool|JsonOutputObject|Redirect
     * @throws Exception
     * @throws NeniPravoException
     */
    public function odhlasitZPlanuKurzuZamestnance($cisloSkoleni, $osoba)
    {
        if (!$cisloSkoleni || !$osoba){
            throw new Exception(\Ron\ronText('nezadano_cislo_skoleni_nebo_osoba'));
        }

        $pp = PracovniPomer::nactiPP($this->database, $osoba);
        if (!$this->pravoPrihlasit->lzeZobrazitRC($pp ->rc) && !$this->pravoSchvalit->lzeZobrazitRC($pp ->rc)){
            throw new NeniPravoException();
        }

        $recZapis = new RonPortalDBRecord($this->database, 'PlanovaneSkoleniOsob', $this);

        $recZapis->addField('CisloSkoleni', '', false);
        $recZapis->addField('RC', '', false);
        $recZapis->addField('Vlozil', '', false);
        $recZapis->addField('Potvrzeni', '', false);
        $recZapis->addField('DatumVlozeni', 'timestamp', false);
        $recZapis->addField('Vyhodnotil', '', false);
        $recZapis->addField('PrihlasenoZAplikace', '', false);
        $recZapis->addField('DatumVyhodnoceni', 'timestamp', false);

        $params = $this->database->createParameters();
        $recZapis->setWhere(
            'RC  = ' . $params->addParameter($pp->rc) .
            ' AND CisloSkoleni = ' . $params->addParameter($cisloSkoleni),
            $params);

        $recZapis->deleteRecord();


        $filtrprihlaseninaplanovaneskoleni = $_SESSION['filtrprihlaseninaplanovaneskoleni'];
        return new Redirect(null, "?menuid=skoleni&action=prihlaseninaplanovaneskoleni&filtrprihlaseninaplanovaneskoleni=$filtrprihlaseninaplanovaneskoleni");
    }



    /**
     * @param string $action
     * @return InternalRedirect|OutputObject|Redirect|ViewObject|string
     * @throws DBException
     * @throws Exception
     */
    public function handleAction($action)
    {
        if (!($this->pravoPrihlasit->jsouNejakePrava() || $this->pravoSchvalit->jsouNejakePrava())){
            throw new Exception(\Ron\ronText('Nemate_pravo'));
        }

        if (isset($_GET['action'])) {

            if ($_GET['action'] == 'prihlaseninaplanovaneskoleni') {
                if (isset($_POST['plankurzuzamestnance'])) {
                    // odeslani dialogu pro schvaleni/zruseni (s poznamkou)
                    switch ($_POST['plankurzuzamestnance']) {
                        case 'schvalit' :
                            return $this->schvalitPlanKurzuZamestnance($_POST['cisloskoleni'], (int)$_POST['osoba'], 1, $_POST['poznamkaSchvalovani'], $_POST['hromadne']);

                        case 'zrusit' :
                            return $this->odhlasitZPlanuKurzuZamestnance($_POST['cisloskoleni'], (int)$_POST['osoba']);

                        case 'zamitnout' :
                            return $this->schvalitPlanKurzuZamestnance($_POST['cisloskoleni'], (int)$_POST['osoba'], 2, $_POST['poznamkaSchvalovani'], (int)$_POST['hromadne']);
                    }
                } else if (isset($_GET['plankurzuzamestnance'])) {
                    //Schvalovani planu kurzu z odkazu
                    $hromadne = isset($_GET['hromadne']) ? (int)$_GET['hromadne'] : 0;

                    switch ($_GET['plankurzuzamestnance']) {
                        case 'schvalit' :
                            return $this->schvalitPlanKurzuZamestnance($_GET['cisloskoleni'], $_GET['osoba'], 1, null, $hromadne);

                        case 'zrusit' :
                            return $this->odhlasitZPlanuKurzuZamestnance($_GET['cisloskoleni'], $_GET['osoba']);

                        case 'zamitnout' :
                            return $this->schvalitPlanKurzuZamestnance($_GET['cisloskoleni'], $_GET['osoba'], 2, null, $hromadne);
                    }
                }
            } else switch ($_GET['action']) {
                case 'prihlasit':
                    return $this->prihlaseniNaPlanovaneSkoleni($_GET['cisloskoleni']);

                case 'odhlasit':
                    return $this->odhlaseniZPlanovanehoSkoleni($_GET['cisloskoleni']);

                case 'translations':
                    return $this->translations();
            }
        }


        $filtrPrihlaseniNaPlanovaneSkoleni = isset($_GET['filtrprihlaseninaplanovaneskoleni'])
            ? $_GET['filtrprihlaseninaplanovaneskoleni']
            : '';

        if (!$filtrPrihlaseniNaPlanovaneSkoleni && isset($_SESSION['filtrprihlaseninaplanovaneskoleni'])){
            $filtrPrihlaseniNaPlanovaneSkoleni = $_SESSION['filtrprihlaseninaplanovaneskoleni'];
        }


        if ($filtrPrihlaseniNaPlanovaneSkoleni == 'planypodlekurzu' && !isset($_GET['plankurzuzamestnance']))
        {
            $b = new SchvalovaniPlanuKurzuBrowser($this->database, $filtrPrihlaseniNaPlanovaneSkoleni);
            $b->load();
            return $b;
        }

        $b = new SchvalovaniPlanuOsobyBrowser($this->database, 'planypodleosoby');
        $b->load();
        return $b;
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/skoleni/prihlaseninaplanovaneskolenicontroller.php <==
<?php
/**
 * stanislav.elbl, 01.08.2021 10:51
 */

namespace RonPortal\Skoleni;

use Exception;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\Http\HtmlHeaders;
use Ron\MessageManager;
use Ron\MVC\InternalRedirect;
use Ron\MVC\JsonOutputObject;
use Ron\MVC\OutputObject;
use Ron\MVC\Redirect;
use Ron\MVC\ViewObject;
use Ron\StringUtils;
use Ron\TextManager;
use Ron\MVC\HttpController;
use RonPortal\NeniPravoException;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;
use RonPortal\RonPortalDBRecord;
use RonPortal\RonPortalUtils;
use RonPortal\User;


/**
 * Class PrihlaseniNaPlanovaneSkoleniController
 * @package Ron\RonPortal
 */
class PrihlaseniNaPlanovaneSkoleniController extends HttpController
{
    /** @var  PravaNaOsoby $pravoPrihlasit */
    public $pravoPrihlasit;

    /** @var  Database */
    private $database;

    /** @var PravaNaOsoby $pravoSchvalit */
    public $pravoSchvalit;

    /**
     * PrihlaseniNaPlanovaneSkoleniController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;

        Prava::nastavObdobiProPrava(time(), time());
        $this->pravoPrihlasit = Prava::vratPrava('skoleni_prihlasit');
        $this->pravoSchvalit = Prava::vratPrava('skoleni_schvaleni_planu');

        TextManager::getInstance()->loadStrings('prihlaseninaplanovanaskoleni.ini');

        HtmlHeaders::getInstance()->addScript('script/skoleni.js'); // pro funkci "prihlasit s pripojenim poznamky"

        $this ->addTranslationsScript('skoleni');
    }


    /**
     * @param $cisloSkoleni
     * @return Redirect
     * @throws Exception
     */
    public function prihlaseniNaPlanovaneSkoleni($cisloSkoleni)
    {
        if (!$this->pravoPrihlasit->lzeZobrazitRC(User::getRC()) && !$this->pravoSchvalit->lzeZobrazitRC(User::getRC())) {
            throw new NeniPravoException();
        }

        try {
            //Dotaz na volne misto
            $volnaMista = SkoleniUtils::volnaKapacitaPlanovanehoSkoleni($this ->database, $cisloSkoleni);

            if ($volnaMista <= 0) {
                throw new Exception(TextManager::_('chyba_kapacita_kurzu_naplnena'));
            }

            $recZapis = new RonPortalDBRecord($this->database, 'PlanovaneSkoleniOsob', $this);

            $recZapis->addField('CisloSkoleni', '', false, 10, $cisloSkoleni);
            $recZapis->addField('RC', '', false, 15, User::getRC());
            //Pokud ma pravo schvalit sebe
            $muzeSchvalit = $this->pravoSchvalit->lzeZobrazitRC(User::getRC());
            $recZapis->addField('Potvrzeni', 'int', false, 0, ($muzeSchvalit) ? 1 : 0);
            $recZapis->addField('DatumVlozeni', 'timestamp', false, 0, time());
            $recZapis->addField('Vlozil', '', false, 25, User::getRC());
            $recZapis->addField('Vyhodnotil', '', false, 25, '');
            $recZapis->addField('PrihlasenoZAplikace', 'int', false, 0, 1);
            $recZapis->addField('DatumVyhodnoceni', 'timestamp', false, 0, '');

            $params = $this->database->createParameters();
            $recZapis->setWhere(
                'RC  = ' . $params->addParameter(User::getRC()) .
                ' AND CisloSkoleni = ' . $params->addParameter($cisloSkoleni),
                $params);

            if ($recZapis->loadRecord()) {
                throw new Exception(TextManager::_('chyba_osoba_na_skoleni_uz_prihlasena'));
            }

            $recZapis->insertRecord();
        } catch (Exception $e) {
            MessageManager::addErrorMessage($e);
        }

        return new Redirect(null,
            '?menuid=skoleni&action=prihlaseninaplanovaneskoleni');
    }


    /**
     * @param $cisloSkoleni
     * @return Redirect
     * @throws Exception
     */
    public function odhlaseniZPlanovanehoSkoleni($cisloSkoleni)
    {
        if (!$this->pravoPrihlasit->lzeZobrazitRC(User::getRC()) && !$this->pravoSchvalit->lzeZobrazitRC(User::getRC())){
            throw new NeniPravoException();
        }

        $recZapis = new RonPortalDBRecord($this->database, 'PlanovaneSkoleniOsob');

        $params = $this->database->createParameters();
        $recZapis->logDescription = StringUtils::fromUTF8('Plánované školení - odhlašování z plánovaného školení');
        $recZapis->addField('CisloSkoleni', '', false);
        $recZapis->addField('RC', '', false);
        $recZapis->addField('Potvrzeni', '', false);
        $recZapis->addField('Vlozil', '', false);
        $recZapis->addField('DatumVlozeni', 'timestamp', false);
        $recZapis->addField('Vyhodnotil', '', false);
        $recZapis->addField('DatumVyhodnoceni', 'timestamp', false);
        $recZapis->addField('PrihlasenoZAplikace', '', false);

        $recZapis->setWhere( 'RC  = ' . $params->addParameter(User::getRC()) .
            ' AND CisloSkoleni = ' . $params->addParameter($cisloSkoleni), $params);

        if (!$recZapis->deleteRecord()) {
            throw new Exception(StringUtils::fromUTF8('Chyba při odhlašování z plánovaného školení.'));
        }

        $filtrprihlaseninaplanovaneskoleni = $_SESSION['filtrprihlaseninaplanovaneskoleni'];
        return new Redirect(null, "?menuid=skoleni&action=prihlaseninaplanovaneskoleni&filtrprihlaseninaplanovaneskoleni=$filtrprihlaseninaplanovaneskoleni");
    }



    /**
     * @param string $cisloSkoleni
     * @param int    $osoba
     * @param int    $potvrzeni     0=bez rozhodnuti, 1=schvaleno, 2=zamitnuto
     * @param string $poznamkaSchvalovani
     * @param int    $hromadne      Urcuje, jestli se ma presmerovat na hromadne prihlasovani, nebo na prihlasovani osoby
     * @return Redirect
     * @throws Exception
     * @throws NeniPravoException
     */
    public function schvalitPlanKurzuZamestnance($cisloSkoleni, $osoba, $potvrzeni, $poznamkaSchvalovani=null, $hromadne = 0)
    {
        if (!$cisloSkoleni || !$osoba){
            throw new Exception(\Ron\ronText('chyba_nezadano_cislo_skoleni_nebo_osoba'));
        }

        $pp = PracovniPomer::nactiPP($this->database, $osoba);

        if (!$this->pravoPrihlasit->lzeZobrazitPP($pp->idPP) && !$this->pravoSchvalit->lzeZobrazitPP($pp->idPP)){
            throw new NeniPravoException();
        }

        try {
            //Dotaz na volne misto
            $volnaMista = SkoleniUtils::volnaKapacitaPlanovanehoSkoleni($this ->database, $cisloSkoleni);

            if ($volnaMista <= 0) {
                MessageManager::addErrorMessage(\Ron\ronText('kapacita_kurzu_naplnena'));
            }

            $muzeSchvalit = $this->pravoSchvalit->lzeZobrazitRC($pp->rc);

            $recZapis = new RonPortalDBRecord($this->database, 'PlanovaneSkoleniOsob', $this);

            $recZapis->addField('CisloSkoleni', '', false, 10, $cisloSkoleni);
            $recZapis->addField('RC', '', false, 15, $pp->rc);

            // Pokud ma pravo schvalit danou osobu tak primo schvalit
            $recZapis->addField('Potvrzeni', 'int', !$muzeSchvalit, 0, ($muzeSchvalit) ? $potvrzeni : 0);
            $recZapis->addField('Vlozil', '', true, 25, RonPortalUtils::getLogUserName());
            $recZapis->addField('DatumVlozeni', 'timestamp', true, 0, time());
            $recZapis->addField('Vyhodnotil', '', true, 25, '');
            $recZapis->addField('DatumVyhodnoceni', 'timestamp', true, 0, '');
            $recZapis->addField('PrihlasenoZAplikace', 'int', true, 0, 1);

            //pri odhlaseni zustane poznamka zachovana
            $recZapis->addMemoField('PoznamkaSchvalovani', !isset($poznamkaSchvalovani), $poznamkaSchvalovani);

            $params = $this->database->createParameters();
            $recZapis->setWhere(
                'RC  = ' . $params->addParameter($pp->rc) .
                ' AND CisloSkoleni = ' . $params->addParameter($cisloSkoleni),
                $params);


            $recZapis->updateOrInsert();
        } catch (Exception $e) {
            MessageManager::addErrorMessage($e);
        }

//        if ($ajax){
//            //Pokud je prihlaseni/schvaleni pomoci dialogu via ajax
//            $json = new JsonOutputObject();
//            $json->setResult('OK');
//            return $json;
//        }

        $redirectFiltr = $hromadne ? 'planypodlekurzu' : 'planypodleosoby';
        return new Redirect(null, "?menuid=skoleni&action=prihlaseninaplanovaneskoleni&filtrprihlaseninaplanovaneskoleni=$redirectFiltr");
    }


    /**
     * @param string $cisloSkoleni
     * @param int $osoba
     * @return bool|JsonOutputObject|Redirect
     * @throws Exception
     * @throws NeniPravoException
     */
    public function odhlasitZPlanuKurzuZamestnance($cisloSkoleni, $osoba)
    {
        if (!$cisloSkoleni || !$osoba){
            throw new Exception(\Ron\ronText('nezadano_cislo_skoleni_nebo_osoba'));
        }

        $pp = PracovniPomer::nactiPP($this->database, $osoba);
        if (!$this->pravoPrihlasit->lzeZobrazitRC($pp ->rc) && !$this->pravoSchvalit->lzeZobrazitRC($pp ->rc)){
            throw new NeniPravoException();
        }

        $recZapis = new RonPortalDBRecord($this->database, 'PlanovaneSkoleniOsob', $this);

        $recZapis->addField('CisloSkoleni', '', false);
        $recZapis->addField('RC', '', false);
        $recZapis->addField('Vlozil', '', false);
        $recZapis->addField('Potvrzeni', '', false);
        $recZapis->addField('DatumVlozeni', 'timestamp', false);
        $recZapis->addField('Vyhodnotil', '', false);
        $recZapis->addField('PrihlasenoZAplikace', '', false);
        $recZapis->addField('DatumVyhodnoceni', 'timestamp', false);

        $params = $this->database->createParameters();
        $recZapis->setWhere(
            'RC  = ' . $params->addParameter($pp->rc) .
            ' AND CisloSkoleni = ' . $params->addParameter($cisloSkoleni),
            $params);

        $recZapis->deleteRecord();


        $filtrprihlaseninaplanovaneskoleni = $_SESSION['filtrprihlaseninaplanovaneskoleni'];
        return new Redirect(null, "?menuid=skoleni&action=prihlaseninaplanovaneskoleni&filtrprihlaseninaplanovaneskoleni=$filtrprihlaseninaplanovaneskoleni");
    }



    /**
     * @param string $action
     * @return InternalRedirect|OutputObject|Redirect|ViewObject|string
     * @throws DBException
     * @throws Exception
     */
    public function handleAction($action)
    {
        if (!($this->pravoPrihlasit->jsouNejakePrava() || $this->pravoSchvalit->jsouNejakePrava())){
            throw new Exception(\Ron\ronText('Nemate_pravo'));
        }

        if (isset($_GET['action'])) {

            if ($_GET['action'] == 'prihlaseninaplanovaneskoleni') {
                if (isset($_POST['plankurzuzamestnance'])) {
                    // odeslani dialogu pro schvaleni/zruseni (s poznamkou)
                    switch ($_POST['plankurzuzamestnance']) {
                        case 'schvalit' :
                            return $this->schvalitPlanKurzuZamestnance($_POST['cisloskoleni'], (int)$_POST['osoba'], 1, $_POST['poznamkaSchvalovani'], $_POST['hromadne']);

                        case 'zrusit' :
                            return $this->odhlasitZPlanuKurzuZamestnance($_POST['cisloskoleni'], (int)$_POST['osoba']);

                        case 'zamitnout' :
                            return $this->schvalitPlanKurzuZamestnance($_POST['cisloskoleni'], (int)$_POST['osoba'], 2, $_POST['poznamkaSchvalovani'], (int)$_POST['hromadne']);
                    }
                } else if (isset($_GET['plankurzuzamestnance'])) {
                    //Schvalovani planu kurzu z odkazu
                    $hromadne = isset($_GET['hromadne']) ? (int)$_GET['hromadne'] : 0;

                    switch ($_GET['plankurzuzamestnance']) {
                        case 'schvalit' :
                            return $this->schvalitPlanKurzuZamestnance($_GET['cisloskoleni'], $_GET['osoba'], 1, null, $hromadne);

                        case 'zrusit' :
                            return $this->odhlasitZPlanuKurzuZamestnance($_GET['cisloskoleni'], $_GET['osoba']);

                        case 'zamitnout' :
                            return $this->schvalitPlanKurzuZamestnance($_GET['cisloskoleni'], $_GET['osoba'], 2, null, $hromadne);
                    }
                }
            } else switch ($_GET['action']) {
                case 'prihlasit':
                    return $this->prihlaseniNaPlanovaneSkoleni($_GET['cisloskoleni']);

                case 'odhlasit':
                    return $this->odhlaseniZPlanovanehoSkoleni($_GET['cisloskoleni']);

                case 'translations':
                    return $this->translations();
            }
        }


        $filtrPrihlaseniNaPlanovaneSkoleni = $_GET['filtrprihlaseninaplanovaneskoleni'] ?? '';

        if (!$filtrPrihlaseniNaPlanovaneSkoleni && isset($_SESSION['filtrprihlaseninaplanovaneskoleni'])){
            $filtrPrihlaseniNaPlanovaneSkoleni = $_SESSION['filtrprihlaseninaplanovaneskoleni'];
        }


        if ($filtrPrihlaseniNaPlanovaneSkoleni == 'planypodlekurzu' && !isset($_GET['plankurzuzamestnance']))
        {
            $b = new SchvalovaniPlanuKurzuBrowser($this->database, $filtrPrihlaseniNaPlanovaneSkoleni);
            $b->load();
            return $b;
        }

        $b = new SchvalovaniPlanuOsobyBrowser($this->database, 'planypodleosoby');
        $b->load();
        return $b;
    }
}
